@@ -148,8 +148,8 @@ class CascadeCMSRestDriver:
             f'Getting access rights for {asset_type} asset {asset_identifier} with URL {url}')
         return self.session.get(url).json()
 
-    def copy_asset_to_new_container(self, asset_identifier: str = '', new_name: str = '', destination_container_identifier: str = ''):
-        url = f'{self.base_url}/api/v1/copy/{asset_identifier}'
+    def copy_asset_to_new_container(self, asset_type: str = 'page', asset_identifier: str = '', new_name: str = '', destination_container_identifier: str = ''):
+        url = f'{self.base_url}/api/v1/copy/{asset_type}/{asset_identifier}'
         return self.session.post(
             url,
             data=json.dumps({
